@@ -14,10 +14,6 @@
 
 #include "layershellqt_export.h"
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 6, 0)
-struct xdg_popup;
-#endif
-
 namespace LayerShellQt
 {
 class WindowPrivate;
@@ -120,10 +116,6 @@ public:
      */
     static Window *get(QWindow *window);
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 6, 0)
-    static void attachPopup(QWindow *window, xdg_popup *popup);
-#endif
-
     static Window *qmlAttachedProperties(QObject *object);
 
 Q_SIGNALS:
